#
# spec file for package tasque
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define dbus_min_version 0.60-26
%if 0%{?suse_version}
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
%else
%define suse_update_desktop_file true
%endif
Name:           tasque
Version:        0.1.12
Release:        bp156.3.47
Summary:        A simple task management app (TODO list) for the Linux Desktop
License:        LGPL-2.1-or-later AND MIT
Group:          Productivity/Office/Organizers
URL:            http://live.gnome.org/Tasque
Source:         http://download.gnome.org/sources/tasque/0.1/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  mono-data-sqlite
BuildRequires:  mono-devel
BuildRequires:  notify-sharp
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(dbus-sharp-1.0)
BuildRequires:  pkgconfig(dbus-sharp-glib-1.0)
Requires:       dbus-1-glib >= %{dbus_min_version}
Requires:       dbus-1-x11 >= %{dbus_min_version}
Requires:       mono-data-sqlite
Recommends:     %{name}-lang
Provides:       tasky = %{version}
Obsoletes:      tasky < %{version}

%description
Tasky is a simple task management app (TODO list) for the Linux
Desktop.

%lang_package

%prep
%setup -q
translation-update-upstream

%build
%configure \
    --enable-standard-backends
make %{?_smp_mflags}

%install
%make_install
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file %{name}
%fdupes -s %{buildroot}

%if 0%{?suse_version} > 1130
%post
%desktop_database_post
%icon_theme_cache_post
%endif

%if 0%{?suse_version} > 1130
%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%{_bindir}/%{name}
%{_prefix}/lib/pkgconfig/tasque.pc
%{_prefix}/lib/tasque/
%{_datadir}/applications/tasque.desktop
%{_datadir}/dbus-1/services/org.gnome.Tasque.service
%{_datadir}/icons/hicolor/*/apps/tasque*.*
%{_datadir}/pixmaps/tasque-*.png
%{_datadir}/tasque/

%files lang -f %{name}.lang

%changelog
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Nov 17 2015 badshah400@gmail.com
- Add Requries: mono-data-sqlite to fix crash (boo#955052).
* Tue May 19 2015 zaitor@opensuse.org
- Replace mono(Mono.Data.Sqlite) for mono-data-sqlite, as rpm does
  not pull the package when using the former.
* Tue May 12 2015 dimstar@opensuse.org
- Add mono(Mono.Data.Sqlite) BuildRequires: ensure the mono SQL
  connector is available during build.
* Sun Nov 18 2012 zaitor@opensuse.org
- Drop BuildRequires: pkgconfig(gconf-2.0), no longer needed.
* Tue Oct 30 2012 dimstar@opensuse.org
- Update to version 0.1.12:
  + xbuild is now used for the build. An interface for autotools
    build is still in place.
  + Tasque for Windows now features a msi installer.
  + gtk-update-icon-cache is not run anymore after install.
  + configure checks now for Mono.Data.Sqlite
  + Fix for "recurring tasks" (bgo#656608)
  + Fix for "Crashes on startup in Windows 7" (bgo#634158)
  + Fix for "Remove gnome-sharp and gconf dependencies"
    (bgo#670391)
  + Fix for "Tasque build-depends on gtk-dotnet-sharp" (bgo#568910)
  + Adding task by clicking anywhere in the window now possible,
    (bgo#566499)
  + Use dbus-sharp instead of NDesk.DBus (bgo#671553)
  + Fix "Normal characters are escaped in notewidget label"
    (bgo#538017)
  + Imitate tooltip in AppIndicator using a MenuItem (bgo#649670)
  + Other bug fixes: bgo#668422, bgo#656513, bgo#653354,
    bgo#649752, bgo#578279, bgo#566355.
  + Updated translations.
* Sun Sep  2 2012 dimstar@opensuse.org
- Update to version 0.1.11:
  + Internal cleanup.
  + Updated translations.
- Changes from version 0.1.10:
  + Fixed some automake issues.
  + Tasque runs now on .NET 4 profile.
  + Added support for Ubuntu/Unity's Application Indicator in
    addition to Gtk's StatusIcon.
  + Fixed "Unable to complete tasks in RTM" bug. Side effect: Smart
    lists are temporarily not supported by Tasque.
  + Evolution backend disabled.
  + Bugs fixed: bgo#557792, bgo#578279, bgo#645040, bgo#570517,
    bgo#579428, bgo#591090, bgo#614505, bgo#607816, bgo#555680,
    bgo#613969.
  + Updated translations.
- Drop evolution-sharp BuildRequires: no longer needed, as the
  evolution backend has been disabled.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Feb 16 2010 vuntz@opensuse.org
- Update to version 0.1.9:
  + Support for Mono >= 2.6
  + Support for enabling groups of backends when building:
  - -enable-standard-backends, --enable-experimental-backends and
  - -enable-all-backends.
  + Customizable color highlighting in tasks.
  + Clear "New Task..." text in inputfield on drag and drop.
  + Option to change category via context menu.
  + Hiveminder improvements.
  + Close task window on ESC keypress.
  + Initial implementation of tooltip for the tray icon.
  + Bugs fixes: bgo#540983, bgo#567730, bgo#555242, bgo#533182
    bgo#532915, bgo#534749, bgo#566052, bgo#563748, bgo#563748,
    bgo#572074, bgo#567947, bgo#609712, bgo#574521
  + Updated translations.
- Drop tasque-fix-rtmnet-dir.patch: fixed upstream.
- Pass --enable-standard-backends to configure instead of
  - -enable-backend-rtm --enable-backend-sqlite --enable-backend-eds
  - -enable-backend-hiveminder.
- Remove tr_TR locale workaround: not needed anymore.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update the way we remove the tr_TR locale.
* Fri Oct  2 2009 vuntz@opensuse.org
- Add tasque-fix-rtmnet-dir.patch to make tasque work on x86_64.
  Fix bnc#538983.
- Do not add category to desktop file that is already there.
- Do not call intltoolize/autoreconf.
- Add a Provides to completement the Obsoletes of tasky, and make
  them versioned. Fix a rpmlint warning.
- Other minor cleanups.
* Mon Jan 26 2009 vuntz@novell.com
- On openSUSE <= 11.1, exclude locales unknown to the system.
* Thu Jan 22 2009 vuntz@novell.com
- Review changes, and sanitize a bit the file list.
* Thu Dec 25 2008 mboman@suse.de
- Update to version 0.1.8:
  + Initial support for Windows and Mac OS X
  + Update Remember The Milk backend to work with latest rememberthemilk.com
  + SQLite backend improvements
  + Much improved DBus interface
  + Better info in status bar, including cool countdown when completing tasks.
  + Experimental new Hiveminder backend
  + Better GTK+ theme compliance
  + Add --quiet command line option to start with window hidden
  + Add --debug, --trace, and --profile command line options
  + Several crash fixes
  + Bugs fixed: bgo#562026, bgo#556549, bgo#532766, bgo#562845, bgo#526662,
    bgo#563932, bgo#551717, bgo#564344, bgo#562729, bgo#561430, bgo#540983,
    bgo#537911, bgo#542113, bgo#552944, bgo#555921, bgo#555168, bgo#538019,
    bgo#533033, bgo#526492, bgo#532274, bgo#534760, bgo#555028, bgo#560640,
    bgo#554352
* Sat Sep  6 2008 mboman@novell.com
- Updated to version 0.1.7
  + Make translations actually work.
  + Add tooltips that show notes for a task
  + Bugs fixed: bgo#525281, bgo#543245, bgo#540588, bgo#539781,
    bgo#541190
  + Translation updates
- Reviewed work from awafaa@opensuse.org
* Wed Aug  6 2008 awafaa@opensuse.org
- Update to latest release 0.1.6
  + New task entry widget at top of Tasque window.
  + When entering a new task, parse for due date information.
  + Cleaner SVG icon
  + Use Gtk.StatusIcon
  + Crash fixes
  + Bugs fixed: bgo#525306, bgo#525282, bgo#536740, bgo#532764
    bgo#526663, bgo#525272, bgo#538144, bgo#533609, bgo#533607
- Remove patch as it is integrated in the new release
* Thu Jun 12 2008 mauro@suse.de
- Added eds and sqlite backends to fix bnc#399862.
* Mon May 26 2008 jpr@suse.de
- Make sure tasque-exe-config-fix-bnc382448.patch is applied properly
* Thu May 15 2008 btimothy@suse.de
- Add Tasque.exe.config.in to specify the proper dll libraries.
  This fixes BNC #382448, crash at startup.
* Wed Apr  2 2008 maw@suse.de
- Import into autobuild.
* Wed Mar 19 2008 calvinrg@gmail.com
- Added notify-sharp as a BuildRequires so that we'll build
  with notification support to notify the user when a
  task is created via the DBus interface.
* Thu Mar 13 2008 btimothy@gmail.com
- Added notify-sharp as a Requires so that we'll build
  with notification support to notify the user when a
  task is created via the DBus interface.
* Thu Mar 13 2008 btimothy@gmail.com
- Fix up prefix/lib so the tasque.pc file works on
  x86_64 builds.
* Thu Mar 13 2008 btimothy@gmail.com
- Updated the spec file to better build for SLE_10 by
  specifying specific DBus requirements.
* Thu Mar 13 2008 btimothy@gmail.com
- Added 'Obsoletes: tasky'
* Wed Mar 12 2008 calvinrg@gmail.com
- Updated to 0.1.5.
- Renamed package to Tasque
* Fri Mar  7 2008 btimothy@gmail.com
- Updated to 0.1.4.
- Removed tasky-remove-show-expanders.patch since it's
  included in the tarball now.
* Tue Feb 19 2008 btimothy@gmail.com
- Added tomboy-remove-show-expanders.patch so tasky will
  build on older distros.
* Tue Feb 19 2008 btimothy@gmail.com
- Updated to 0.1.3.
* Sat Feb 16 2008 btimothy@gmail.com
- Updated to 0.1.1.
- Use tar.gz since that's what Tasky's site publishes.
* Thu Feb 14 2008 btimothy@gmail.com
- Use official 0.1.0 release.
* Thu Feb 14 2008 ajorgensen@novell.com
- Initial import
